@@ -13,7 +13,7 @@ use HTTP::Response;
 use LWP::UserAgent;
 use JSON;
 
-our $VERSION = '0.092_01';
+our $VERSION = '0.092_02';
 
 our $CANNED_RESPONSE_DIR = File::Spec->catdir(
     qw{ t data Mock-LWP-UserAgent } );
@@ -26,9 +26,9 @@ $LOG_FILE_NAME
     1;
 } or $LOG_FILE_NAME = undef;
 
-my %original = map { $_ => LWP::UserAgent->can( $_ ) } qw{
-    new cookie_jar env_proxy get head post put request
-};
+## my %original = map { $_ => LWP::UserAgent->can( $_ ) } qw{
+##     new cookie_jar env_proxy get head post put request
+## };
 
 sub import {
 
